<?php

namespace Teknisa\MAN\Services;

use Doctrine\ORM\EntityManager;
use Teknisa\MAN\Utilities\Query;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;

class TipoSangriaService {

    const SUCCESS_PC = "SUCCESS";
    // erro na exportação
    const ERROR_PC = "ERROR";
    protected $connection;

    public function __construct($entityManager) {
        $this->entityManager = $entityManager;
    }
  
    public function exportisang($dataExport){
        $status = null;
        $data   = $dataExport;
        try {
            self::controlTransaction('begin');            
        } catch (Exception $e) {
            return self::ERROR_PC;
        }
        $this->exportAllProd($data);
        return $status;
    }

    public function controlTransaction($type){
    // controla transação com banco    
        try {
            switch ($type) {
                case 'begin':
                // inicia transação sem auto-commit
                    $this->entityManager->getConnection()->beginTransaction();
                    break;
                case 'commit':
                // salva transação
                    $this->entityManager->getConnection()->commit();
                    break;
                case 'rollback':
                // descarta transação
                    $this->entityManager->getConnection()->rollBack();
                    break;
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function exportAllProd($data){
        $paramsQuery = array();

        try {
            self::formatSangriaOri($paramsQuery, $data);
            $data['cdtpsangriaorigi'] = $this->entityManager->getConnection()->fetchAll(self::GET_ALL_ORIGIN_SANGRIA, $paramsQuery);
            foreach($data['CDFILIALDES'] as $destino){
                
                self::formatsSangriaOri($paramsQuery,$data, $destino);
                $this->entityManager->getConnection()->executeQuery(self::INSERT_ORIGIN_SANGRIA, $paramsQuery);
            }
            self::controlTransaction('commit');
            return self::SUCCESS_PC;
        } catch (Exception $e) {
            self::controlTransaction('rollback');
            return self::ERROR_PC;
        }
    }

    
  
    
    public function formatSangriaOri(&$paramsQuery, $data){
        $paramsQuery = array(
          'CDFILIAL' => $data['CDFILIAL'],
          'NRORG'       => $data['NRORG']
        );
    }

    public function formatsSangriaOri(&$paramsQuery, $data, $destino){
        
        $paramsQuery = array(
          'CDFILIALDES' => $destino,
          'CDFILIALORI' => $data['CDFILIAL'],
          'NRORG'    => $data['NRORG']
        );
    }
    
    public function formatSangriaDes(&$paramsQuery, $data, $destino, $produto){
        $paramsQuery = array(
          'CDFILIALDES' => $destino,
          'CDTPSANGRIAORI'=> $produto['CDTPSANGRIA'],
          'NRORG'       => $data['NRORG']
        );
    }
    
      const GET_ALL_ORIGIN_SANGRIA = "
    	select cdtpsangria from tiposangria where cdfilial=:CDFILIAL and NRORG=:NRORG

    ";

    const DELETE_DESTINY_SANGRIA = "
      DELETE FROM tiposangria WHERE CDFILIAL = :CDFILIALDES AND cdtpsangria = :CDTPSANGRIAORI AND NRORG = :NRORG 
    ";

    const INSERT_ORIGIN_SANGRIA = "
     INSERT INTO tiposangria
        ( CDFILIAL, CDTPSANGRIA,NMTPSANGRIA,NRORG,IDATIVO,IDSANGRIA)
        SELECT
        :CDFILIALDES,
         CDTPSANGRIA,
         NMTPSANGRIA,
         NRORG,
         IDATIVO,
         IDSANGRIA
        FROM
            TIPOSANGRIA 
        WHERE
            ( CDFILIAL = :CDFILIALORI )
            AND NRORG = :NRORG
            AND CDTPSANGRIA NOT IN (
                SELECT
                    CDTPSANGRIA
                FROM
                    TIPOSANGRIA 
                WHERE
                    ( CDFILIAL = :CDFILIALDES )
                    AND NRORG = :NRORG
            )
    ";
      
}